Module: Bundler::Spinel

Defined in:
lib/bundler/spinel.rb,
lib/bundler/spinel/cli.rb,
lib/bundler/spinel/site.rb,
lib/bundler/spinel/probe.rb,
lib/bundler/spinel/proxy.rb,
lib/bundler/spinel/engine.rb,
lib/bundler/spinel/ledger.rb,
lib/bundler/spinel/server.rb,
lib/bundler/spinel/survey.rb,
lib/bundler/spinel/checker.rb,
lib/bundler/spinel/command.rb,
lib/bundler/spinel/history.rb,
lib/bundler/spinel/version.rb,
lib/bundler/spinel/enricher.rb,
lib/bundler/spinel/platform.rb,
lib/bundler/spinel/vendorer.rb,
lib/bundler/spinel/verifier.rb,
lib/bundler/spinel/localizer.rb,
lib/bundler/spinel/gem_fetcher.rb,
lib/bundler/spinel/test_runner.rb,
lib/bundler/spinel/ext_detector.rb,
lib/bundler/spinel/engine_installer.rb

Defined Under Namespace

Modules: Scaffold, TestRunner Classes: CLI, Checker, Command, Engine, EngineInstaller, Enricher, Error, ExtDetector, GemFetcher, History, Ledger, Localizer, Platform, Probe, Proxy, Server, Site, Survey, Vendorer, Verifier

Constant Summary collapse

VERSION =

First published release: the Gemfile convention + ‘spinel-compat vendor` are proven, and `install-engine` now provisions the compiler too, so a newcomer can `gem install bundler-spinel` and onboard without an out-of-band Spinel build (spinelgems#9).

"0.2.0"